==> vb-react-form-0.1.7.tgz: package/es/FormsV1/Form/index.js <==
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import PropTypes from 'prop-types';
import { FormModel } from './FormModel';
import { FormItem } from './FormItem';
import { FormField, FieldErrors } from '../FormField';
import { connectForm } from './decorator';

var VBForm = function (_React$PureComponent) {
  _inherits(VBForm, _React$PureComponent);

  function VBForm(props) {
    _classCallCheck(this, VBForm);

    var _this = _possibleConstructorReturn(this, _React$PureComponent.call(this, props));

    _this.onSubmit = function (e) {
      e.preventDefault();
      if (_this.model.isValid()) {
        _this.model.makeSubmitted();
        _this.props.onSubmit(_this.model.values(), _this.model.getPublic());
      }
    };

    _this.model = new FormModel(props.name, props.validator, props.onChange);
    return _this;
  }

  VBForm.prototype.getChildContext = function getChildContext() {
    return { formModel: this.model };
  };

  VBForm.prototype.componentDidMount = function componentDidMount() {
    this.model.validate();
    this.model.completed();
    this.props.onLoad(this.model.getPublic());
  };

  VBForm.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    // console.log(22222, nextProps);
  };

  VBForm.prototype.componentDidUpdate = function componentDidUpdate() {
    this.model.refresh();
  };

  VBForm.prototype.componentWillUnmount = function componentWillUnmount() {
    this.model.willDelete();
  };

  VBForm.prototype.render = function render() {
    var _props = this.props,
        children = _props.children,
        onSubmit = _props.onSubmit,
        onChange = _props.onChange,
        validator = _props.validator,
        other = _objectWithoutProperties(_props, ['children', 'onSubmit', 'onChange', 'validator']);

    return React.createElement(
      'form',
      _extends({ onSubmit: this.onSubmit }, other),
      children
    );
  };

  return VBForm;
}(React.PureComponent);

VBForm.propTypes = {
  name: PropTypes.string,
  validator: PropTypes.func,
  children: PropTypes.any.isRequired,
  onLoad: PropTypes.func,
  onChange: PropTypes.func,
  onSubmit: PropTypes.func
};
VBForm.defaultProps = {
  name: null,
  validator: function validator() {
    return {};
  },
  onLoad: function onLoad() {},
  onChange: function onChange() {},
  onSubmit: function onSubmit() {}
};
VBForm.childContextTypes = {
  formModel: PropTypes.instanceOf(FormModel).isRequired
};


VBForm.Field = FormField;
VBForm.Errors = FieldErrors;
VBForm.Item = FormItem;

export { VBForm, FormModel, connectForm };

==> vb-react-form-0.1.9.tgz: package/es/FormsV1/Form/index.js <==
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import PropTypes from 'prop-types';
import { FormModel } from './FormModel';
import { FormItem } from './FormItem';
import { FormField, FieldErrors } from '../FormField';
import { connectForm } from './decorator';

var VBForm = function (_React$PureComponent) {
  _inherits(VBForm, _React$PureComponent);

  function VBForm(props) {
    _classCallCheck(this, VBForm);

    var _this = _possibleConstructorReturn(this, _React$PureComponent.call(this, props));

    _this.onSubmit = function (e) {
      e.preventDefault();
      if (_this.model.isValid()) {
        _this.model.makeSubmitted();
        _this.props.onSubmit(_this.model.values(), _this.model.getPublic());
      }
    };

    _this.model = new FormModel(props.name, props.validator, props.onChange);
    return _this;
  }

  VBForm.prototype.getChildContext = function getChildContext() {
    return { formModel: this.model };
  };

  VBForm.prototype.componentDidMount = function componentDidMount() {
    this.model.validate();
    this.model.completed();
    this.props.onLoad(this.model.getPublic());
  };

  VBForm.prototype.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {};

  VBForm.prototype.componentDidUpdate = function componentDidUpdate() {
    // this.model.refresh();
  };

  VBForm.prototype.componentWillUnmount = function componentWillUnmount() {
    this.model.willDelete();
  };

  VBForm.prototype.render = function render() {
    var _props = this.props,
        children = _props.children,
        onSubmit = _props.onSubmit,
        onChange = _props.onChange,
        validator = _props.validator,
        other = _objectWithoutProperties(_props, ['children', 'onSubmit', 'onChange', 'validator']);

    return React.createElement(
      'form',
      _extends({ onSubmit: this.onSubmit }, other),
      children
    );
  };

  return VBForm;
}(React.PureComponent);

VBForm.propTypes = {
  name: PropTypes.string,
  validator: PropTypes.func,
  children: PropTypes.any.isRequired,
  onLoad: PropTypes.func,
  onChange: PropTypes.func,
  onSubmit: PropTypes.func
};
VBForm.defaultProps = {
  name: null,
  validator: function validator() {
    return {};
  },
  onLoad: function onLoad() {},
  onChange: function onChange() {},
  onSubmit: function onSubmit() {}
};
VBForm.childContextTypes = {
  formModel: PropTypes.instanceOf(FormModel).isRequired
};


VBForm.Field = FormField;
VBForm.Errors = FieldErrors;
VBForm.Item = FormItem;

export { VBForm, FormModel, connectForm };
